@@ -1,6 +1,8 @@
 import logging
 from functools import partial
-from typing import Optional, Callable, Any
+from typing import Optional, Callable
+
+from docker import DockerClient
 
 from .container import DockerContainer
 from .utils import wait_is_ready, inside_container
@@ -13,14 +15,16 @@ logger = logging.getLogger(__name__)
 class PostgresContainer(DockerContainer):
 
     def __init__(self,
-                 check_connection_callback: Callable[[str], Any],
+                 check_connection_callback: Callable[[str], bool],
                  user: str = 'user',
                  password: str = 'pass',
                  database: Optional[str] = None,
                  image: str = 'postgres:11-alpine',
-                 port_to_expose: int = 5432):
+                 port_to_expose: int = 5432,
+                 client: Optional[DockerClient] = None,
+                 ):
 
-        super(PostgresContainer, self).__init__(image=image)
+        super(PostgresContainer, self).__init__(image=image, client=client)
         self.check_connection_callback = check_connection_callback
         self.user = user
         self.password = password
